bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 18. Aventiure
___________________________________________________ #### Auenture wie Chriemh' da bestvnt vn– ir #### sweher dannen reit [41v]
| ### <Do> brahte man den herren da er Chriemh' vant ### er sprach zer kvniginne wir svln in vnser lant ### wir wæn vnmære geste hie ze Rinne sin ### min vil liebiv frowe nv vart ir zv den landen min ### Sit daz vns untriwe ane hat getan ### hie in disen landen des ivren edeln man ### des ensvlt ir niht engelten ich wil iv wæge sin ### durch mins svns liebe des svlt ir gar ane angest sin
###### 1086 | ### Ir svlt ovch haben frowe allen den gewalt ### den iv e tet kunde der chuone degn balt ### daz lant vn– ovch die chrone daz si iv vndertan ### iv svln gerne dienen alle Sivrides man
###### 1087 | ### Do sagte man den knehten si solden riten dan ### do wart ein michel gahen nah rossen getan ### bi ir starchen uinden was in ze wesen leit ### der frowen un– ir mægeden hiez man svchen div kleit
| ### Do der kunic Sigemunt wolde sin geriten ### do begunden Chriemh' ir besten frivnde biten ### daz si bi ir frivnden solde da bestan ### do sprach div kuniginne daz chunde mvlich ergan
###### 1089 | ### Wie moht ich den mit ovgen immer an gesehn ### von dem mir armem wibe so leide ist geschehn ### do sprach ir bruder Giselher vil liebiv swester min ### dv solt durch dine triwe hie bi diner mvoter sin
###### 1090 | ### Die dir <da> hant betrvbet den lip un– ovch den mvot ### der bedarfstv vil chleine. zer min eines gvot ### si sprach zvo dem degene wie chunde daz geschehn ### vor leide mves ich sterben swenne ich Hagenen solde sehn
###### 1091 | ### Des tvon ich dir ze rate vil liebiv swester min ### dv solt bi dinen brvder Giselhere sin ### ich wil dich ergezzen dines mannes tot ### do sprach div kuniginne des wær mir armen wibe not
| ### Do ez ir der iunge so gvotlich erbot ### si begunden vlegen Vote vn– Gernot ### vn– ir getriwen mage si baten da bestan ### si hete luzzil frivnde bi den Sivrides man
###### 1093 | ### Si simt iv alle fremede so sprach Gernot ### niemen lebt so starcher ern mvze ligen tot ### daz bedenchet swester vn– getrostet ivren mvot ### belibet bi den friunden ez wirt iv wærlichen gvot
###### 1094 | ### Do lobte si ir magen si wolde da bestan ### div ross bereitet warn den Sigemundes man ### also si wolden riten heim in Niderlant ### si heten vf gesovmet al der rechen gewant
###### 1095 | ### Do gie der herre Sigemvnt zv Chriemh' stan ### er sprach zv der frowen die Sivrides man ### iv wartent bi den rossen wir svln riten hin ### wande ich vil vngerne bi den Buregonden bin
###### 1096 | ### Do sprach div frowe Chriemh' mir ratent frivnde min ### swaz ich han der getriwen ich svle hie bi in sin ### ich habe luzzel mage in Nibelunge lant ### leit was ez Sigemunde do er div mære an ir ervant [42r]
###### 1097 | ### Do sprach der kunic Sigemvnt daz enlat iv niemen sagen ### vor allen minen magen svlt ir chrone tragen ### alsam gewaltekliche als ir ê habt getan ### irn svlt des niht engelten daz wir den helt verlorn han
###### 1098 | ### Vn– vart ovch mit vns widere durch iwer kindelin ### daz ensvlt ir so niht frowe verweiset lazen sin ### swenne iwer svon gewæhset der trostet iv den mvot ### die wile sol iv dienen von rechen manic helt gvot
###### 1099 | ### Si sprach herre Sigemunt ine mac geriten niht ### ich mvoz hie beliben swaz halt mir geschiht ### bi den minen magen daz si mir helfen klagn ### do begunde disiv mære den gvten rechen missehagn
###### 1100 | ### Si sprachen al geliche so mohten wir wol gehn ### daz vns allererste wære leit geschehn ### ob ir beliben woldet bi vnsern uinden hie ### so geriten hovereise noch helde sorchlicher nie
| ### Ir sult ane alle sorge gote bevolhen varn ### ich schaffe iv gvot geleite vn– heiz ivch wol bewarn ### zv Sigemundes lande min liebez kindelin ### daz sol vf genade iv rechen wol bevolhen sin
###### 1102 | ### Do si daz <vernamen> daz si niht wolde dan ### do weinten al gemeine die Sivrides man ### wie rehte iæmerliche sich schiet Sigemunt ### von der kuniginne do was im vngemvete chunt
###### 1103 | ### We geschehe der hochgecite sprach der kunic her ### ez geschiht von churcewile leider nimmer mer ### deheinen kuniges magen danne vns ist geschehn ### man sol vns nimmer mere hie zen Buregonden sehn
###### 1104 | ### Do sprachen offenliche die Sivrides mann ### ez mohte noch ein reise in dizze lant ergan ### so wir den reht erfunden der vns den herren erslvoch ### si hant von sinen magen der starchen vinde genvoch
| ### Er chuste Chriemh' wie iæmerlich er sprach ### do si niht riten wolde vn– ez daz reht ersach ### nv riten vrevden ane heim in unser lant ### alle mine sorge sint mir erste nv bechant
###### 1106 | ### Si riten vngeleitet von Wormez zetal den Rin ### si mohten sicherlichen wol des mvtes sin ### ob si in vintschefte wrden an gerant ### daz sich wem wolde der chunen Nibelunge hant
###### 1107 | ### Sine gerten vrlovbes da ze cheinem man ### do sah man Gernoten vn– Giselhern gan ### zvo zim minneklichen in was sin schade leit ### des brahten in wol innen die helde kvn vn– gemeit
| ### Do sprach gezogenliche der kunic Gernot ### <got> weiz daz wol von himele an Sivrides tot ### gewan ich nie die schulde daz ich daz horte sagn ### wer im hie vint wêre ich sol in pilliche klagen
###### 1109 | ### Do gab in sin geleite Giselher daz kint ### er brahte sorgende vz dem lande sint ### den kunic mit sinen rechen heim ze Niderlant ### wie luzzil man der [42v]mage dar inne vroliche vant
###### 1110 | ### Wie si nv gefuoren des enkan ich niht gesagn ### man horte zallen citen hie Chriemh' klagn ### daz ir niemen troste daz herce vn– ovch den mvot ### ez entæt ir brvder Giselher der was getriwe un– gvot
###### 1111 | ### Prvnh' div schone mit vbermvte saz ### swaz Chriemh' geweinte vnmære was ir daz ### sine wart ir rehter triwen nimmer me bereit ### sit geriet ovch ir vroe Chriemh' ich wæn als ungefvegiv leit

<<< Übersicht <<< vorige Seite nächste Seite >>>